import getopt
import sys

from influxdb import InfluxDBClient
from json import load


def generate_network_measurements(influx_host, db_name, network_config_path):
    """
    Generates network measurements which follow the telegraf ping plugin format.

    :param influx_host: influx DB host
    :param db_name: name of database
    :param network_config_path the path to the network configuration file
    """

    with open(network_config_path) as fh:
        json_data = load(fh)

    # declares the data to push to influx - host, url, avg_response_ms, min_response_ms, max_response_ms
    data = ((link["source"], link["target"], link["avg_response_time"], link["min_response_time"], link["max_response_time"]) for link in json_data["links"])

    json_body = [
        {"measurement": "ping",
         "tags": {"host": host, "url": url},
         "fields": {"packets_transmitted": 10, "reply_received": 10, "packets_received": 10,
                    "percent_reply_loss": 0, "percent_packets_loss": 0, "errors": 0, "average_response_ms": avg_ms,
                    "minimum_response_ms": min_ms, "maximum_response_ms": max_ms, "result_code": 0},
         "time": 1528385860 * 10**9
         } for host, url, avg_ms, min_ms, max_ms in data
    ]

    print("Establishing connection with influx DB on {0} with database {1}".format(influx_host, db_name))
    db_client = InfluxDBClient(host=influx_host, timeout=10, database=db_name)
    db_client.drop_measurement("ping")  # clear data in the ping measurement from previous executions of this script
    print("Writing network latency data to influx..\n")
    assert db_client.write_points(json_body)  # assert the write method returns True - successful write


if __name__ == "__main__":
    try:
        opts, args = getopt.getopt(sys.argv[1:], "h:d:p:", ['host=', 'database=', 'path='])
    except getopt.GetoptError:
        print('generate_network_measurements.py -h <influx host> -d <influx database> -p <network configuration file path>')
        sys.exit(1)

    if len(opts) != 3:
        print('generate_network_measurements.py -h <influx host> -d <influx database> -p <network configuration file path>')
        sys.exit(1)

    db_host, database, path = None, None, None
    # Apply options, if any
    for opt, arg in opts:
        if opt in ('-h', '--host'):
            db_host = arg
        elif opt in ('-d', '--database'):
            database = arg
        elif opt in ('-p', '--path'):
            path = arg

    if all([db_host is not None, database is not None, path is not None]):
        generate_network_measurements(db_host, database, path)
